@@ -92,7 +92,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.9';
+our $VERSION = '0.91';
 
 
 sub process
@@ -183,7 +183,7 @@ sub site_dir
 
 Copyright 2003 - MKDoc Holdings Ltd.
 
-Author: Jean-Michel Hiver <jhiver@mkdoc.com>
+Author: Jean-Michel Hiver
 
 This module is free software and is distributed under the same license as Perl
 itself. Use it at your own risk.
@@ -191,7 +191,7 @@ itself. Use it at your own risk.
 
 =head1 SEE ALSO
 
-  Petal: http://search.cpan.org/author/JHIVER/Petal/
+  L<Petal> TAL for perl
   MKDoc: http://www.mkdoc.com/
 
 Help us open-source MKDoc. Join the mkdoc-modules mailing list:
