@@ -319,7 +319,7 @@ __END__
 
 Copyright 2003 - MKDoc Holdings Ltd.
 
-Author: Jean-Michel Hiver <jhiver@mkdoc.com>
+Author: Jean-Michel Hiver
 
 This module is free software and is distributed under the same license as Perl
 itself. Use it at your own risk.
@@ -327,7 +327,7 @@ itself. Use it at your own risk.
 
 =head1 SEE ALSO
 
-  Petal: http://search.cpan.org/author/JHIVER/Petal/
+  L<Petal> TAL for perl
   MKDoc: http://www.mkdoc.com/
 
 Help us open-source MKDoc. Join the mkdoc-modules mailing list:
